@@ -13,10 +13,7 @@ import cdk8s_plus_17._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@Hunter-Thompson/cdk8s-redis-sts",
-    "0.0.2",
-    __name__[0:-6],
-    "cdk8s-redis-sts@0.0.2.jsii.tgz",
+    "cdk8s-redis-sts", "0.0.5", __name__[0:-6], "cdk8s-redis-sts@0.0.5.jsii.tgz"
 )
 
 __all__ = [
